@@ -1,8 +1,28 @@
+#
+# Copyright (c) 2013+ Anton Tyurin <noxiouz@yandex.ru>
+# Copyright (c) 2013+ Evgeny Safronov <division494@gmail.com>
+# Copyright (c) 2011-2014 Other contributors as noted in the AUTHORS file.
+#
+# This file is part of Cocaine-tools.
+#
+# Cocaine is free software; you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# Cocaine is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
+
 import logging
 import os
 import re
 import shutil
-import sys
 import tarfile
 import tempfile
 
@@ -100,7 +120,11 @@ class Remove(actions.Storage):
             if self.name not in apps:
                 raise ToolsError('application "{0}" does not exist'.format(self.name))
             yield self.storage.remove('manifests', self.name)
-            yield self.storage.remove('apps', self.name)
+            try:
+                yield self.storage.remove('apps', self.name)
+            except ServiceError:
+                log.info('Unable to delete an application source from storage.',
+                         'It\'s okay, if the application is a Docker image')
 
 
 class Start(common.Node):
@@ -131,9 +155,10 @@ class Stop(common.Node):
 
 
 class Restart(common.Node):
-    def __init__(self, node, locator, name, profile):
+    def __init__(self, node, locator, name, profile, storage):
         super(Restart, self).__init__(node)
         self.locator = locator
+        self.storage = storage
         self.name = name
         self.profile = profile
         if not self.name:
@@ -142,7 +167,7 @@ class Restart(common.Node):
     @chain.source
     def execute(self):
         try:
-            info = yield NodeInfo(self.node, self.locator).execute()
+            info = yield NodeInfo(self.node, self.locator, self.storage).execute()
             profile = self.profile or info['apps'][self.name]['profile']
             appStopStatus = yield Stop(self.node, name=self.name).execute()
             appStartStatus = yield Start(self.node, name=self.name, profile=profile).execute()
@@ -179,23 +204,28 @@ class Check(common.Node):
 
 
 class DockerUpload(actions.Storage):
-    def __init__(self, storage, path, name, manifest, address, registry=''):
+    def __init__(self, storage, path, name, manifest, address, registry='', on_read=None):
         super(DockerUpload, self).__init__(storage)
         self.path = path or os.path.curdir
         self.name = name or os.path.basename(os.path.abspath(self.path))
         if registry:
             self.fullname = '{0}/{1}'.format(registry, self.name)
+        else:
+            self.fullname = self.name
 
         self.manifest = manifest
 
         self.client = docker.Client(address)
 
         log.debug('checking Dockerfile')
-        if not os.path.exists(os.path.join(self.path, 'Dockerfile')):
-            raise ValueError('Dockerfile not found')
         if not address:
             raise ValueError('Docker address is not specified')
 
+        if on_read is not None:
+            if not callable(on_read):
+                raise ValueError("on_read must ne callable")
+            self._on_read = on_read
+
         self._last_message = ''
 
     @engine.asynchronous
@@ -205,7 +235,11 @@ class DockerUpload(actions.Storage):
         if self.manifest:
             manifestPath = self.manifest
         else:
-            manifestPath = _locateFile(self.path, 'manifest.json')
+            try:
+                manifestPath = _locateFile(self.path, 'manifest.json')
+            except IOError:
+                log.error("unable to locate manifest.json")
+                raise ToolsError("unable to locate manifest.json")
 
         with printer('Loading manifest'):
             manifest = CocaineConfigReader.load(manifestPath)
@@ -213,13 +247,20 @@ class DockerUpload(actions.Storage):
         with printer('Uploading manifest'):
             yield self.storage.write('manifests', self.name, manifest, APPS_TAGS)
 
-        response = yield self.client.build(self.path, tag=self.fullname, streaming=sys.stderr.write)
-        if response.code != 200:
-            raise ToolsError('upload failed with error code {0}'.format(response.code))
+        try:
+            response = yield self.client.build(self.path, tag=self.fullname, streaming=self._on_read)
+            if response.code != 200:
+                raise ToolsError('building failed with error code {0} {1}'.format(response.code,
+                                                                                  response.body))
 
-        response = yield self.client.push(self.fullname, {}, streaming=self._on_read)
-        if response.code != 200:
-            raise ToolsError('upload failed with error code {0}'.format(response.code))
+            response = yield self.client.push(self.fullname, {}, streaming=self._on_read)
+            if response.code != 200:
+                raise ToolsError('pushing failed with error code {0} {1}'.format(response.code,
+                                                                                 response.body))
+        except Exception as err:
+            log.error("Error occurred. Erase manifest")
+            yield self.storage.remove('manifests', self.name)
+            raise err
 
     def _on_read(self, value):
         if self._last_message != value:
