@@ -1,8 +1,30 @@
+#
+# Copyright (c) 2013+ Anton Tyurin <noxiouz@yandex.ru>
+# Copyright (c) 2013+ Evgeny Safronov <division494@gmail.com>
+# Copyright (c) 2011-2014 Other contributors as noted in the AUTHORS file.
+#
+# This file is part of Cocaine-tools.
+#
+# Cocaine is free software; you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# Cocaine is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
+
 import types
 
 from cocaine.futures import chain
 from cocaine.tools import actions, log
 from cocaine.tools.actions import CocaineConfigReader
+from cocaine.tools.printer import printer
 from cocaine.tools.tags import RUNLISTS_TAGS
 
 __author__ = 'Evgeny Safronov <division494@gmail.com>'
@@ -37,9 +59,8 @@ class Upload(Specific):
     @chain.source
     def execute(self):
         runlist = CocaineConfigReader.load(self.runlist)
-        log.info('Uploading "%s"... ', self.name)
-        yield self.storage.write('runlists', self.name, runlist, RUNLISTS_TAGS)
-        log.info('OK')
+        with printer('Uploading "%s"', self.name):
+            yield self.storage.write('runlists', self.name, runlist, RUNLISTS_TAGS)
 
 
 class Create(Specific):
@@ -114,7 +135,7 @@ class RemoveApplication(Specific):
         runlist = yield View(self.storage, name=self.name).execute()
         log.debug('Found runlist: {0}'.format(runlist))
         if runlist.pop(self.app, None) is None:
-            result['the application named {0} is not in runlist'.format(self.app)]
+            result['status'] = 'the application named {0} is not in runlist'.format(self.app)
         else:
             runlistUploadAction = Upload(self.storage, name=self.name, runlist=runlist)
             yield runlistUploadAction.execute()
