@@ -1,3 +1,24 @@
+#
+# Copyright (c) 2013+ Anton Tyurin <noxiouz@yandex.ru>
+# Copyright (c) 2013+ Evgeny Safronov <division494@gmail.com>
+# Copyright (c) 2011-2014 Other contributors as noted in the AUTHORS file.
+#
+# This file is part of Cocaine-tools.
+#
+# Cocaine is free software; you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published
+# by the Free Software Foundation; either version 3 of the License, or
+# (at your option) any later version.
+#
+# Cocaine is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program. If not, see <http://www.gnu.org/licenses/>.
+#
+
 import collections
 import logging
 import os
@@ -115,15 +136,22 @@ crashlogDispatcher = Dispatcher(globaloptions=Global.options, middleware=middlew
 proxyDispatcher = Dispatcher()
 
 
-@d.command()
-def info(options):
+@d.command(name='info', usage='[--name=NAME]')
+def info(options,
+         name=('n', '', 'application name'),
+         expand=('', False, 'expand all nesting info (like profile)')):
     """Show information about cocaine runtime
 
     Return json-like string with information about cocaine-runtime.
+
+    If the name option is not specified, shows information about all applications.
     """
     options.executor.executeAction('info', **{
         'node': options.getService('node'),
-        'locator': options.locator
+        'locator': options.locator,
+        'storage': options.getService('storage') if expand else None,
+        'name': name,
+        'expand': expand
     })
 
 
@@ -293,6 +321,7 @@ def app_restart(options,
     """
     options.executor.executeAction('app:restart', **{
         'node': options.getService('node'),
+        'storage': options.getService('storage'),
         'locator': options.locator,
         'name': name,
         'profile': profile
@@ -341,6 +370,17 @@ def profile_upload(options,
     })
 
 
+@profileDispatcher.command(name='edit')
+def profile_edit(options,
+                 name):
+    """Edit profile in interactive editor."""
+    options.executor.timeout = None
+    options.executor.executeAction('profile:edit', **{
+        'storage': options.getService('storage'),
+        'name': name,
+    })
+
+
 @profileDispatcher.command(name='remove')
 def profile_remove(options,
                    name=('n', '', 'profile name')):
@@ -369,6 +409,17 @@ def runlist_view(options,
     })
 
 
+@runlistDispatcher.command(name='edit', usage='NAME')
+def runlist_edit(options,
+                 name):
+    """Edit runlist interactively."""
+    options.executor.timeout = None
+    options.executor.executeAction('runlist:edit', **{
+        'storage': options.getService('storage'),
+        'name': name
+    })
+
+
 @runlistDispatcher.command(name='upload')
 def runlist_upload(options,
                    name=('n', '', 'name'),
@@ -489,6 +540,20 @@ def crashlog_removeall(options,
     })
 
 
+@crashlogDispatcher.command(name='clean')
+def crashlog_clean(options,
+                   name=('n', '', 'name'),
+                   timestamp=('t', '', 'timestamp'),
+                   size=('s', 1000, 'size')):
+    """For application [NAME] leave [SIZE] crashlogs or remove all crashlogs with timestamp > [TIMESTAMP]."""
+    options.executor.executeAction('crashlog:clean', **{
+        'storage': options.getService('storage'),
+        'name': name,
+        'size': size,
+        'timestamp': timestamp
+    })
+
+
 @dispatcher.group.command(name='list', usage='')
 def group_list(options):
     """Show routing groups.
